@@ -1,21 +1,27 @@
-###################################################################################################
+################################################################################
 # Module: buildings.py
 # Description: Download and plot building footprints from OpenStreetMap
 # License: MIT, see full license in LICENSE.txt
 # Web: https://github.com/gboeing/osmnx
-###################################################################################################
+################################################################################
 
 import time
 import geopandas as gpd
 import matplotlib.pyplot as plt
 from matplotlib.collections import PatchCollection
-from shapely.geometry import Polygon, MultiPolygon, Point
+from shapely.geometry import Polygon
+from shapely.geometry import MultiPolygon
 from descartes import PolygonPatch
 
-from .projection import project_geometry
+from .core import consolidate_subdivide_geometry
+from .core import get_polygons_coordinates
+from .core import overpass_request
+from .core import bbox_from_point
+from .core import gdf_from_place
 from .plot import save_and_show
-from .core import consolidate_subdivide_geometry, get_polygons_coordinates, overpass_request, bbox_from_point, gdf_from_place
-from .utils import log, geocode
+from .projection import project_geometry
+from .utils import log
+from .utils import geocode
 
 
 def osm_bldg_download(polygon=None, north=None, south=None, east=None, west=None,
@@ -38,10 +44,13 @@ def osm_bldg_download(polygon=None, north=None, south=None, east=None, west=None
     timeout : int
         the timeout interval for requests and to pass to API
     memory : int
-        server memory allocation size for the query, in bytes. If none, server will use its default allocation size
+        server memory allocation size for the query, in bytes. If none, server
+        will use its default allocation size
     max_query_area_size : float
-        max area for any part of the geometry, in the units the geometry is in: any polygon bigger will get divided
-        up for multiple queries to API (default is 50,000 * 50,000 units (ie, 50km x 50km in area, if units are meters))
+        max area for any part of the geometry, in the units the geometry is in:
+        any polygon bigger will get divided up for multiple queries to API
+        (default is 50,000 * 50,000 units (ie, 50km x 50km in area, if units are
+        meters))
 
     Returns
     -------
@@ -49,8 +58,9 @@ def osm_bldg_download(polygon=None, north=None, south=None, east=None, west=None
         list of response_json dicts
     """
 
-    # check if we're querying by polygon or by bounding box based on which argument(s) where passed into this function
-    by_poly = not polygon is None
+    # check if we're querying by polygon or by bounding box based on which
+    # argument(s) where passed into this function
+    by_poly = polygon is not None
     by_bbox = not (north is None or south is None or east is None or west is None)
     if not (by_poly or by_bbox):
         raise ValueError('You must pass a polygon or north, south, east, and west')
@@ -59,7 +69,8 @@ def osm_bldg_download(polygon=None, north=None, south=None, east=None, west=None
 
     # pass server memory allocation in bytes for the query to the API
     # if None, pass nothing so the server will use its default allocation size
-    # otherwise, define the query's maxsize parameter value as whatever the caller passed in
+    # otherwise, define the query's maxsize parameter value as whatever the
+    # caller passed in
     if memory is None:
         maxsize = ''
     else:
@@ -71,43 +82,58 @@ def osm_bldg_download(polygon=None, north=None, south=None, east=None, west=None
         polygon = Polygon([(west, south), (east, south), (east, north), (west, north)])
         geometry_proj, crs_proj = project_geometry(polygon)
 
-        # subdivide it if it exceeds the max area size (in meters), then project back to lat-long
+        # subdivide it if it exceeds the max area size (in meters), then project
+        # back to lat-long
         geometry_proj_consolidated_subdivided = consolidate_subdivide_geometry(geometry_proj, max_query_area_size=max_query_area_size)
-        geometry, crs = project_geometry(geometry_proj_consolidated_subdivided, crs=crs_proj, to_latlong=True)
+        geometry, _ = project_geometry(geometry_proj_consolidated_subdivided, crs=crs_proj, to_latlong=True)
         log('Requesting building footprints data within bounding box from API in {:,} request(s)'.format(len(geometry)))
         start_time = time.time()
 
-        # loop through each polygon rectangle in the geometry (there will only be one if original bbox didn't exceed max area size)
+        # loop through each polygon rectangle in the geometry (there will only
+        # be one if original bbox didn't exceed max area size)
         for poly in geometry:
-            # represent bbox as south,west,north,east and round lat-longs to 8 decimal places (ie, within 1 mm) so URL strings aren't different due to float rounding issues (for consistent caching)
+            # represent bbox as south,west,north,east and round lat-longs to 8
+            # decimal places (ie, within 1 mm) so URL strings aren't different
+            # due to float rounding issues (for consistent caching)
             west, south, east, north = poly.bounds
-            query_template = '[out:json][timeout:{timeout}]{maxsize};((way["building"]({south:.8f},{west:.8f},{north:.8f},{east:.8f});(._;>;););(relation["building"]({south:.8f},{west:.8f},{north:.8f},{east:.8f});(._;>;);));out;'
+            query_template = ('[out:json][timeout:{timeout}]{maxsize};((way["building"]({south:.8f},'
+                              '{west:.8f},{north:.8f},{east:.8f});(._;>;););(relation["building"]'
+                              '({south:.8f},{west:.8f},{north:.8f},{east:.8f});(._;>;);));out;')
             query_str = query_template.format(north=north, south=south, east=east, west=west, timeout=timeout, maxsize=maxsize)
             response_json = overpass_request(data={'data':query_str}, timeout=timeout)
             response_jsons.append(response_json)
-        log('Got all building footprints data within bounding box from API in {:,} request(s) and {:,.2f} seconds'.format(len(geometry), time.time()-start_time))
+        msg = ('Got all building footprints data within bounding box from '
+               'API in {:,} request(s) and {:,.2f} seconds')
+        log(msg.format(len(geometry), time.time()-start_time))
 
     elif by_poly:
-        # project to utm, divide polygon up into sub-polygons if area exceeds a max size (in meters), project back to lat-long, then get a list of polygon(s) exterior coordinates
+        # project to utm, divide polygon up into sub-polygons if area exceeds a
+        # max size (in meters), project back to lat-long, then get a list of polygon(s) exterior coordinates
         geometry_proj, crs_proj = project_geometry(polygon)
         geometry_proj_consolidated_subdivided = consolidate_subdivide_geometry(geometry_proj, max_query_area_size=max_query_area_size)
-        geometry, crs = project_geometry(geometry_proj_consolidated_subdivided, crs=crs_proj, to_latlong=True)
+        geometry, _ = project_geometry(geometry_proj_consolidated_subdivided, crs=crs_proj, to_latlong=True)
         polygon_coord_strs = get_polygons_coordinates(geometry)
         log('Requesting building footprints data within polygon from API in {:,} request(s)'.format(len(polygon_coord_strs)))
         start_time = time.time()
 
-        # pass each polygon exterior coordinates in the list to the API, one at a time
+        # pass each polygon exterior coordinates in the list to the API, one at
+        # a time
         for polygon_coord_str in polygon_coord_strs:
-            query_template = '[out:json][timeout:{timeout}]{maxsize};(way(poly:"{polygon}")["building"];(._;>;);relation(poly:"{polygon}")["building"];(._;>;));out;'
+            query_template = ('[out:json][timeout:{timeout}]{maxsize};(way'
+                              '(poly:"{polygon}")["building"];(._;>;);relation'
+                              '(poly:"{polygon}")["building"];(._;>;));out;')
             query_str = query_template.format(polygon=polygon_coord_str, timeout=timeout, maxsize=maxsize)
             response_json = overpass_request(data={'data':query_str}, timeout=timeout)
             response_jsons.append(response_json)
-        log('Got all building footprints data within polygon from API in {:,} request(s) and {:,.2f} seconds'.format(len(polygon_coord_strs), time.time()-start_time))
+        msg = ('Got all building footprints data within polygon from API in '
+               '{:,} request(s) and {:,.2f} seconds')
+        log(msg.format(len(polygon_coord_strs), time.time()-start_time))
 
     return response_jsons
 
 
-def create_buildings_gdf(polygon=None, north=None, south=None, east=None, west=None, retain_invalid=False):
+def create_buildings_gdf(polygon=None, north=None, south=None, east=None,
+                         west=None, retain_invalid=False):
     """
     Get building footprint data from OSM then assemble it into a GeoDataFrame.
 
@@ -147,7 +173,7 @@ def create_buildings_gdf(polygon=None, north=None, south=None, east=None, west=N
                 nodes = result['nodes']
                 try:
                     polygon = Polygon([(vertices[node]['lon'], vertices[node]['lat']) for node in nodes])
-                except:
+                except Exception:
                     log('Polygon has invalid geometry: {}'.format(nodes))
                 building = {'nodes' : nodes,
                             'geometry' : polygon}
@@ -170,7 +196,8 @@ def create_buildings_gdf(polygon=None, north=None, south=None, east=None, west=N
 
 def buildings_from_point(point, distance, retain_invalid=False):
     """
-    Get building footprints within some distance north, south, east, and west of a lat-long point.
+    Get building footprints within some distance north, south, east, and west of
+    a lat-long point.
 
     Parameters
     ----------
@@ -193,7 +220,8 @@ def buildings_from_point(point, distance, retain_invalid=False):
 
 def buildings_from_address(address, distance, retain_invalid=False):
     """
-    Get building footprints within some distance north, south, east, and west of an address.
+    Get building footprints within some distance north, south, east, and west of
+    an address.
 
     Parameters
     ----------
@@ -272,7 +300,8 @@ def plot_buildings(gdf, fig=None, ax=None, figsize=None, color='#333333', bgcolo
     bgcolor : string
         the background color of the plot
     set_bounds : bool
-        if True, set bounds from either passed-in bbox or the spatial extent of the gdf
+        if True, set bounds from either passed-in bbox or the spatial extent of
+        the gdf
     bbox : tuple
         if True and if set_bounds is True, set the display bounds to this bbox
     save : bool
@@ -297,7 +326,8 @@ def plot_buildings(gdf, fig=None, ax=None, figsize=None, color='#333333', bgcolo
         fig, ax = plt.subplots(figsize=figsize, facecolor=bgcolor)
         ax.set_facecolor(bgcolor)
 
-    # extract each polygon as a descartes patch, and add to a matplotlib patch collection
+    # extract each polygon as a descartes patch, and add to a matplotlib patch
+    # collection
     patches = []
     for geometry in gdf['geometry']:
         if isinstance(geometry, Polygon):
@@ -317,7 +347,8 @@ def plot_buildings(gdf, fig=None, ax=None, figsize=None, color='#333333', bgcolo
         ax.set_xlim((left, right))
         ax.set_ylim((bottom, top))
 
-    # turn off the axis display set the margins to zero and point the ticks in so there's no space around the plot
+    # turn off the axis display set the margins to zero and point the ticks in
+    # so there's no space around the plot
     ax.axis('off')
     ax.margins(0)
     ax.tick_params(which='both', direction='in')
